summaryrefslogtreecommitdiff
path: root/.gitlab-ci/run-style-check-diff.sh
diff options
context:
space:
mode:
authorMatthias Clasen <mclasen@redhat.com>2021-11-29 17:37:49 -0500
committerMatthias Clasen <mclasen@redhat.com>2021-11-29 17:37:49 -0500
commitddd5704c923c412ce9024a8383b56d09a8b11950 (patch)
tree5d4faf384a9cf9f44f804fdca0ccb6708e8c2a16 /.gitlab-ci/run-style-check-diff.sh
parent3ba6d2bd27823dc7f60dd027f77de3a0f457ba86 (diff)
downloadgtk+-ddd5704c923c412ce9024a8383b56d09a8b11950.tar.gz
Update references to master in the repository
Diffstat (limited to '.gitlab-ci/run-style-check-diff.sh')
-rwxr-xr-x.gitlab-ci/run-style-check-diff.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/.gitlab-ci/run-style-check-diff.sh b/.gitlab-ci/run-style-check-diff.sh
index 42ef5d9fee..a69fd77308 100755
--- a/.gitlab-ci/run-style-check-diff.sh
+++ b/.gitlab-ci/run-style-check-diff.sh
@@ -2,7 +2,7 @@
set -e
# We need to add a new remote for the upstream master, since this script could
# be running in a personal fork of the repository which has out of date branches.
if [ "${CI_PROJECT_NAMESPACE}" != "GNOME" ]; then
echo "Retrieving the current upstream repository from ${CI_PROJECT_NAMESPACE}/${CI_PROJECT_NAME}..."
@@ -16,7 +16,7 @@ fi
# Work out the newest common ancestor between the detached HEAD that this CI job
# has checked out, and the upstream target branch (which will typically be
-# `upstream/master` or `upstream/gtk-3-24`).
+# `upstream/main` or `upstream/gtk-3-24`).
#
# `${CI_MERGE_REQUEST_TARGET_BRANCH_NAME}` is only defined if we’re running in
# a merge request pipeline; fall back to `${CI_DEFAULT_BRANCH}` otherwise.
@@ -36,7 +36,7 @@ exit_status=$?
echo ""
echo "Note that clang-format output is advisory and cannot always match the"
echo "GTK coding style, documented at:"
-echo " https://gitlab.gnome.org/GNOME/gtk/blob/master/docs/CODING-STYLE"
+echo " https://gitlab.gnome.org/GNOME/gtk/blob/main/docs/CODING-STYLE"
echo "Warnings from this tool can be ignored in favour of the documented "
echo "coding style, or in favour of matching the style of existing"
echo "surrounding code."
@@ -2,7 +2,7 @@
set -e
-# We need to add a new remote for the upstream master, since this script could
+# We need to add a new remote for the upstream main, since this script could
# be running in a personal fork of the repository which has out of date branches.
if [ "${CI_PROJECT_NAMESPACE}" != "GNOME" ]; then